@@ -1,9 +1,9 @@
 package Tapper::Reports::API;
-# git description: v5.0.3-2-g5d24b55
+# git description: v5.0.4-1-ga161e06
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Remote network API for result evaluation
-$Tapper::Reports::API::VERSION = '5.0.4';
+$Tapper::Reports::API::VERSION = '5.0.5';
 use 5.010;
 use strict;
 use warnings;
@@ -105,14 +105,14 @@ sub handle_upload
 {
         my ($self, $report_id, $filename, $contenttype) = @_;
 
-        my $s_filecontent = do { local $/; <STDIN> };
-        $s_filecontent ||= ' ';
+        my $s_filecontent = '';
+        $s_filecontent = do { local $/; <STDIN> };
         return model('TestrunDB')->resultset('ReportFile')->new({
                 report_id   => $report_id,
                 filename    => $filename,
                 filecontent => $s_filecontent,
                 contenttype => $contenttype || 'plain', # 'application/octet-stream',
-        })->insert;
+        })->insert if length($s_filecontent);
 }
 
 sub _parse_args {
